function particles = f_grainsGeneration3D(c, sampleVolume, GC_frac, GC_amount)
%
% determines grains in the mix according to given requirements
%
% f_grainsGeneration3D(sampleVolume, GC_frac, GC_amount)
%
% input: c - volumetric fraction of grains in the composite [-]
%        sampleVolume - volume of the sample containing the aggregates
%        GC_frac - grading curve fractions
%        GC_amount - number (or mass, or volume) of particles in individual
%                    intervals of GC_frac
%
% output: particles = grain diameters in array 
%
% written by Venca 19/2/2013

%% Calculation 

volume_of_particles = c*sampleVolume;
GC_amount = GC_amount*volume_of_particles/sum(GC_amount);
particles = [];

for i = size(GC_frac,1):-1:1
    frac_volume = 0;
    frac_particles = [];
    
    while frac_volume < GC_amount(i)
        particle_radius = 0.5*(GC_frac(i,1)+rand*(GC_frac(i,2)-GC_frac(i,1)));
        frac_volume = frac_volume + 4/3*pi*particle_radius^3;
        frac_particles = [frac_particles; particle_radius];
    end
    
    suggested_volume_high = 4/3*pi*frac_particles.^3;
    suggested_volume_low = 4/3*pi*frac_particles(1:end-1).^3;
    if abs(sum(suggested_volume_high)-GC_amount(i)) > abs(sum(suggested_volume_low)-GC_amount(i))
        frac_particles = frac_particles(1:end-1);
    end
    particles = [particles; frac_particles];
end
particles = particles*2;

end

        
        
        
        
        
