function placedParticles = f_placeParticles(particles,cubeSizeRVE,minDistBetweenGrains,periodicBC)

%%
% places the particles into the RVE
%
% f_placeParticles(particles,cubeSizeRVE,minDistBetweenGrains,periodicBC)
%
% input: particles - grain diameters in array 
%        cubeSizeRVE - size of cubical RVE sample side [m]
%        minDistBetweenGrains - minimum distance between grains [m]
%        periodicBC - true = periodic BC (grains can cross the RVE boundary)
%                     false = grains cannot cross the RVE boundary
%
% output: placedParticles - information about placed particles: 
%                           center_x, center_y, center_z, radius, 
%                            
% written by Venca 27/04/2013
%%

nParticles = length(particles);
placedParticles = zeros(nParticles,4); % center_x, center_y, center_z, radius

displayLimit = 1; % to inform about the progress
displayStep = 1;  % to inform about the progress
firstMessage = false; % to inform about the progress

for j = 1:nParticles
    
    % information about progress
    if ~firstMessage
        fprintf('Particles positioned:  0%%\n');
        firstMessage = true;
    end
    if j/nParticles*100 > displayLimit
        fprintf('\b\b\b\b')
        fprintf('%2.d%%\n', displayLimit);
        displayLimit = displayLimit+displayStep;
    end
    
    % placing of particles
    radius = particles(j)/2;
    test = 0;
    while test == 0
        if periodicBC
            center = [cubeSizeRVE*rand,cubeSizeRVE*rand,cubeSizeRVE*rand];
        else 
            center = [radius+(cubeSizeRVE-2*radius)*rand,radius+(cubeSizeRVE-2*radius)*rand,radius+(cubeSizeRVE-2*radius)*rand];
        end

        placedParticles(j,1) = center(1);
        placedParticles(j,2) = center(2);
        placedParticles(j,3) = center(3);
        placedParticles(j,4) = radius;

        if j == 1; 
            test = 1;
        else        
            for k = 1:(j-1)
                deltaCenter = sqrt(sum((center-(placedParticles(k,1:3))).^2));
                if radius+placedParticles(k,4)+minDistBetweenGrains > deltaCenter 
                    test = 0;
                    break
                else
                    test = 1;
                end
            end
        end
    end     
end
     
end
